
/*
UDP Server
-----------

Server side

   1. Initialize SDL_net library
   2. Open a socket on a specified port
   3. Allocate memory for packets
   4. Wait for a packet from the client
   5. Do something with the packet
   6. Free the memory and quit 

   currently converting all network programming to single "UDP_Service" class so code is neater
   for game programming.
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>


#include "UDP_Server_Service.h"
#include "player.h"
#include "Get_Key.h"

int checkArgs(int, char**);   //checks that valid command args were sent to program
void displayHelp(void);
//int kbhit(void);
//int getch(void);

int main(int argc, char *argv[])
{
  int quit = 0;
  char *msg = new char[10];
  char *cmd = new char[10];
  
  if (!checkArgs(argc, argv))
  {
    fprintf(stderr, "\nInvalid syntax!\n\tupd_client <other_ip> <other_ip's_send_port> <listen_port>\n\n");
    exit(1);
  }
  system("clear");
 
  char *server_ip = argv[1];
  int server_port = atoi(argv[2]);
  int listen_port = atoi(argv[3]);
  
  UDP_Server_Service server(listen_port);
    
  //main loop
  while (!quit)
  {
    
    if (kbhit())
    {
      if (getch() == '\n')
      {
        printf("\n$ "); 
        scanf("%s", cmd);
  
        if (!strcmp(cmd, "send"))
        {
          printf(" > ");
          scanf("%s", msg);
//          server.send_data(msg);
    
          //if packet data contains "quit" do so.
          if (!strcmp(msg, "quit"))
          {
            system("clear");
            printf("msg = %s\n", msg);
            printf("\nClient sent \"quit\" command!\n");
            quit = 1;
          }
        }
	
        else if (!strcmp(cmd, "help"))
          displayHelp();
      
        else if (!strcmp(cmd, "exit"))
          quit = 1;
	  
	else if (!strcmp(cmd, "set_ip"))
	{
	  printf(" > ");
	  scanf("%s", msg);
	  
	  if (!server.resolve_dest_address(msg))
	  {
	    printf("\nAn Error has occurred! The program must exit.\n");
	    quit = 1;
	  }
	}
	
	else if (!strcmp(cmd, "set_port"))
	{
	  printf(" > ");
	  scanf("%s", msg);
	  
	  if(!server.resolve_dest_address(atoi(msg)))
	  {
	    printf("\nAn Error has occurred! The program must exit.\n");
	    quit = 1;
	  }
	}
	
	else if (!strcmp(cmd, "show_dest_info"))
	  server.show_dest_info();
	  
      }
      
    }
    
    if (!server.recieve_data())
      quit = 1;
      
  }
  
  printf("\nTerminating program normally...\n");
  delete [] msg;
  return 0;
  
}

int checkArgs(int a_count, char *a_variable[])
{
  char *choice = new char[1];
 
  if (a_count < 3)
    return 0;
  
  printf("\n   IP Address to connect to: %s", a_variable[1]);
  printf("\n  Port number to connect to: %s", a_variable[2]);
  printf("\nListen port to recieve from: %s", a_variable[3]);
  
  printf("\nIs this correct? [Y/n] ");
  scanf("%s", choice);
  
  if ((!strcmp(choice, "n")) || (!strcmp(choice, "N")))
    return 0;
  else
    return 1;
}

void displayHelp(void)
{
  printf("\n Help:\n");
  printf("\t        set_ip - set ip address to send to\n");
  printf("\t      set_port - set port number to send to\n");
  printf("\tshow_dest_info - displays current destination IP address and port number\n");
  printf("\t          send - send data packet to destination IP address at selected port\n");
  printf("\t          exit - quit program, but don't force other client to quit too\n");
  printf("\t          help - display this message\n\n");
}
